#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 nothunks
version:              0.2.1.0
visibility:           public
id:                   nothunks-0.2.1.0-Im78dK14PnUC0nwzOC0zd9
key:                  nothunks-0.2.1.0-Im78dK14PnUC0nwzOC0zd9
license:              Apache-2.0
copyright:            2018-2024 Input Output Global Inc (IOG)
maintainer:           Marcin Szamotulski <coot@coot.me>
author:               IOG
synopsis:             Examine values for unexpected thunks
description:
    Long lived application data typically should not contain
    any thunks. This library can be used to examine values for
    unexpected thunks, which can then be used in assertions.
    This can be invaluable in avoiding memory leaks, or tracking
    down existing ones.

category:             Development
abi:                  162eae310d873ac1f1aa77801c14cb83
exposed:              True
exposed-modules:      NoThunks.Class
import-dirs:          /usr/lib/ghc-9.6.6/site-local/nothunks-0.2.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/nothunks-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/nothunks-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-nothunks
hs-libraries:         HSnothunks-0.2.1.0-Im78dK14PnUC0nwzOC0zd9
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7 ghc-heap-9.6.6
    stm-2.5.1.0 text-2.0.2 time-1.12.2
    vector-0.13.2.0-5aTe1V6fRGRBDLXlEcUVda
    wherefrom-compat-0.1.1.1-9hKDfSbQqcp4kIY6G5V7mw

haddock-interfaces:   /usr/share/doc/haskell-nothunks/html/nothunks.haddock
haddock-html:         /usr/share/doc/haskell-nothunks/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

